# Serenity

![Serenity Logo](package-icon.png) 

Serenity is an ASP.NET Core / TypeScript application platform that is built on open-source technologies.

It aims to make development easier while reducing maintenance costs by avoiding boilerplate code, reducing the time spent on repetitive tasks, and applying the best software design practices.

## Who/What This Platform Is For

Serenity is best suited to line-of-business (LOB) applications which can be described as programs that contain integrated capabilities and tie into databases, generally with many forms and listing/reporting pages.

It is also a good fit for administrative interfaces of public-facing websites.

Serenity handles most of the internal plumbing for cross-cutting concerns of such applications, including data manipulation, querying, filtering, services, caching, localization, navigation, validation, user access control, and declarative UI.

## Some of the Out-of-the-Box Features
- A modular, service-based web application model
- A code generator (Sergen) to produce initial services/user interface code for an SQL table
- Two-way transformations between C#/TypeScript code that provides build-time error checking and intelli-sense support
- Attribute-based declarative user interfaces implemented via a widget system
- Seamless data-binding through form definitions (form <-> entity <-> service).
- Local/distributed caching and invalidation
- Simple, data-driven reporting, Excel export
- Script bundling, minification, and content versioning (no more F5 / clear browser cache)
- Fluent SQL Builders
- Micro ORM and Dapper integration
- Customizable handlers for REST-like services that work by reusing information in entity classes and do automatic validation.
Attribute-based navigation menu
- UI / Data Localization
- Audit logging

## Where to Look for Information

- Home: https://serenity.is
- Docs: https://serenity.is/docs
- Blog: https://serenity.is/blog
- Demo: https://demo.serenity.is

- GitHub Repo: https://github.com/serenity-is/Serenity
- Change Log: https://github.com/serenity-is/Serenity/blob/master/CHANGELOG.md 
- Issues: https://github.com/serenity-is/Serenity/issues
- Discussions / Q&A: https://github.com/serenity-is/Serenity/discussions

- Serene Application Template:
[Download from VS Marketplace](https://marketplace.visualstudio.com/items?itemName=VolkanCeylan.SereneSerenityApplicationTemplate)
- Serene GitHub Repo: https://github.com/serenity-is/Serene
